@@ -3,7 +3,7 @@
 read.maimages <- function(files=NULL,source="generic",path=NULL,ext=NULL,names=NULL,columns=NULL,other.columns=NULL,annotation=NULL,wt.fun=NULL,verbose=TRUE,sep="\t",quote=NULL,DEBUG=FALSE,...)
 #	Extracts an RG list from a series of image analysis output files
 #	Gordon Smyth. 
-#	1 Nov 2002.  Last revised 3 Feb 2006.
+#	1 Nov 2002.  Last revised 30 Mar 2006.
 #	Use of colClasses added by Marcus Davy, 14 October 2005.
 {
 #	For checking colClasses setup
@@ -179,7 +179,7 @@ read.maimages <- function(files=NULL,source="generic",path=NULL,ext=NULL,names=N
 	}
 	if(source2=="genepix") {
 		if(!is.null(RG$genes$Block) && !is.null(RG$genes$Row) && !is.null(RG$genes$Column)) {
-			RG$printer <- getLayout(RG$genes,guessdups=TRUE)
+			RG$printer <- getLayout(RG$genes,guessdups=FALSE)
 			nblocks <- RG$printer$ngrid.r*RG$printer$ngrid.c
 			if(!is.na(nblocks) && (nblocks>1) && !is.null(obj$X)) {
 				blocksize <- RG$printer$nspot.r*RG$printer$nspot.c
